==> magify-sdk-4.6.5.zip: package/Runtime/Sharp/Model/Analytics/Events/CampaignImpressionEvent.cs <==
using System.Collections.Generic;
using JetBrains.Annotations;
using Newtonsoft.Json;

namespace Magify.Model
{
    internal class CampaignImpressionEvent : IAnalyticsEvent
    {
        [JsonProperty("campaignName")]
        public string CampaignName { get; init; }

        [JsonProperty("impressionNumber")]
        public int ImpressionNumber { get; init; }

        [JsonProperty("sessionImpressionNumber")]
        public int SessionImpressionNumber { get; init; }

        [JsonProperty("campaignTypeImpressionNumber")]
        public int CampaignTypeImpressionNumber { get; init; }

        [JsonProperty("campaignTypeSessionImpressionNumber")]
        public int CampaignTypeSessionImpressionNumber { get; init; }

        [JsonProperty("eventName")]
        public string EventName { get; init; }

        [JsonProperty("eventNumber")]
        public int EventNumber { get; init; }

        [JsonProperty("sessionEventNumber")]
        public int SessionEventNumber { get; init; }

        [JsonProperty("sessionNumber")]
        public int SessionNumber { get; init; }

        [JsonProperty("isDefaultConfig"), CanBeNull]
        public bool? IsDefault { get; init; }

        [JsonProperty("isBasicIntegration"), CanBeNull]
        public bool? IsBasicIntegration { get; init; }

        [JsonProperty("subscriptionStatus")]
        public SubscriptionStatus SubscriptionStatus { get; init; }

        [JsonProperty("inAppStatus")]
        public InAppStatus InAppStatus { get; init; }

        [JsonProperty("parameters"), CanBeNull]
        public Dictionary<string, object> Parameters { get; init; }

        [JsonProperty("mode"), CanBeNull]
        public string Mode { get; init; }

        [JsonProperty("maxLevel")]
        public int? MaxLevel { get; init; }

        [JsonProperty("level")]
        public int? Level { get; init; }

        [JsonProperty("session_id"), CanBeNull]
        public string SessionId { get; init; }

        [JsonProperty("product_id"), CanBeNull]
        public string ProductId { get; init; }

        [JsonProperty("creative_id"), CanBeNull]
        public string ProductIdCreative { get; init; }

        [JsonProperty("store_name")]
        [CanBeNull]
        public PurchaseStore? StoreName { get; set; }

        [JsonProperty("original_app_version")]
        public string AppVersion { get; init; }

        [JsonProperty("timestamp")]
        public double Timestamp { get; init; } = TimestampExtensions.UtcNowTimestamp;

        /// <remarks>
        /// For deserialization
        /// </remarks>
        public CampaignImpressionEvent()
        {
        }

        public CampaignImpressionEvent(
            CampaignImpression impression,
            SubscriptionStatus subscription,
            InAppStatus inApp,
            LevelStateInfo levelState,
            string sessionId,
            string appVersion,
            bool? isBasicIntegration = null)
        {
            CampaignName = impression.CampaignName;
            ImpressionNumber = impression.ImpressionNumber!.Value;
            SessionImpressionNumber = impression.SessionImpressionNumber!.Value;
            CampaignTypeImpressionNumber = impression.CampaignTypeImpressionNumber!.Value;
            CampaignTypeSessionImpressionNumber = impression.CampaignTypeSessionImpressionNumber!.Value;
            EventName = impression.EventName;
            EventNumber = impression.EventNumber!.Value;
            SessionEventNumber = impression.SessionEventNumber!.Value;
            SessionNumber = impression.SessionNumber;
            IsDefault = impression.IsDefaultConfig;
            SubscriptionStatus = subscription;
            InAppStatus = inApp;
            Parameters = impression.Parameters;
            Mode = levelState.Mode;
            MaxLevel = levelState.MaxLevel;
            Level = levelState.Level;
            SessionId = sessionId;
            ProductId = impression.ProductId;
            ProductIdCreative = impression.ProductIdCreative;
            StoreName = impression.StoreName;
            AppVersion = appVersion;
            IsBasicIntegration = isBasicIntegration;
        }
    }
}

==> magify-sdk-4.6.6.zip: package/Runtime/Sharp/Model/Analytics/Events/CampaignImpressionEvent.cs <==
using System.Collections.Generic;
using JetBrains.Annotations;
using Newtonsoft.Json;

namespace Magify.Model
{
    internal class CampaignImpressionEvent : IAnalyticsEvent
    {
        [JsonProperty("campaignName")]
        public string CampaignName { get; init; }

        [JsonProperty("impressionNumber")]
        public int ImpressionNumber { get; init; }

        [JsonProperty("sessionImpressionNumber")]
        public int SessionImpressionNumber { get; init; }

        [JsonProperty("campaignTypeImpressionNumber")]
        public int CampaignTypeImpressionNumber { get; init; }

        [JsonProperty("campaignTypeSessionImpressionNumber")]
        public int CampaignTypeSessionImpressionNumber { get; init; }

        [JsonProperty("eventName")]
        public string EventName { get; init; }

        [JsonProperty("eventNumber")]
        public int EventNumber { get; init; }

        [JsonProperty("sessionEventNumber")]
        public int SessionEventNumber { get; init; }

        [JsonProperty("sessionNumber")]
        public int SessionNumber { get; init; }

        [JsonProperty("isDefaultConfig"), CanBeNull]
        public bool? IsDefault { get; init; }

        [JsonProperty("isBasicIntegration"), CanBeNull]
        public bool? IsBasicIntegration { get; init; }

        [JsonProperty("subscriptionStatus")]
        public SubscriptionStatus SubscriptionStatus { get; init; }

        [JsonProperty("inAppStatus")]
        public InAppStatus InAppStatus { get; init; }

        [JsonProperty("parameters"), CanBeNull]
        public Dictionary<string, object> Parameters { get; init; }

        [JsonProperty("mode"), CanBeNull]
        public string Mode { get; init; }

        [JsonProperty("maxLevel")]
        public int? MaxLevel { get; init; }

        [JsonProperty("level")]
        public int? Level { get; init; }

        [JsonProperty("session_id"), CanBeNull]
        public string SessionId { get; init; }

        [JsonProperty("product_id"), CanBeNull]
        public string ProductId { get; init; }

        [JsonProperty("creative_id"), CanBeNull]
        public string ProductIdCreative { get; init; }

        [JsonProperty("store_name")]
        [CanBeNull]
        public PurchaseStore? StoreName { get; set; }

        [JsonProperty("original_app_version")]
        public string AppVersion { get; init; }

        [JsonProperty("sdk_version"), CanBeNull]
        public string SdkVersion { get; init; }

        [JsonProperty("timestamp")]
        public double Timestamp { get; init; } = TimestampExtensions.UtcNowTimestamp;

        /// <remarks>
        /// For deserialization
        /// </remarks>
        public CampaignImpressionEvent()
        {
        }

        public CampaignImpressionEvent(
            CampaignImpression impression,
            SubscriptionStatus subscription,
            InAppStatus inApp,
            LevelStateInfo levelState,
            string sessionId,
            string appVersion,
            string sdkVersion,
            bool? isBasicIntegration = null)
        {
            CampaignName = impression.CampaignName;
            ImpressionNumber = impression.ImpressionNumber!.Value;
            SessionImpressionNumber = impression.SessionImpressionNumber!.Value;
            CampaignTypeImpressionNumber = impression.CampaignTypeImpressionNumber!.Value;
            CampaignTypeSessionImpressionNumber = impression.CampaignTypeSessionImpressionNumber!.Value;
            EventName = impression.EventName;
            EventNumber = impression.EventNumber!.Value;
            SessionEventNumber = impression.SessionEventNumber!.Value;
            SessionNumber = impression.SessionNumber;
            IsDefault = impression.IsDefaultConfig;
            SubscriptionStatus = subscription;
            InAppStatus = inApp;
            Parameters = impression.Parameters;
            Mode = levelState.Mode;
            MaxLevel = levelState.MaxLevel;
            Level = levelState.Level;
            SessionId = sessionId;
            ProductId = impression.ProductId;
            ProductIdCreative = impression.ProductIdCreative;
            StoreName = impression.StoreName;
            AppVersion = appVersion;
            SdkVersion = sdkVersion;
            IsBasicIntegration = isBasicIntegration;
        }
    }
}
